0.9.9 API documentation: scalar_multiplication.hpp File Reference

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

scalar_multiplication.hpp File Reference

Experimental extensions More...

Go to the source code of this file.

## Detailed Description

Experimental extensions

Author
  Joshua Moerman

Include <glm/gtx/scalar_multiplication.hpp> to use the features of this extension.

Enables scalar multiplication for all types

Since GLSL is very strict about types, the following (often used) combinations do not work: double * vec4 int * vec4 vec4 / int So we'll fix that! Of course "float * vec4" should remain the same (hence the enable_if magic)

Definition in file scalar_multiplication.hpp.